Interface Definitions
=====================

.. automodule:: shoobx.immutable.interfaces

   .. autointerface:: IImmutable
      :members:
      :member-order: bysource

   .. autointerface:: IImmutableObject
      :members:
      :member-order: bysource

   .. autointerface:: IRevisionedImmutableManager
      :members:
      :member-order: bysource

   .. autointerface:: IRevisionedImmutable
      :members:
      :member-order: bysource

